@@ -469,7 +469,7 @@ static const GtkActionEntry actions[] =
 
 static const GtkActionEntry task_actions[] = 
 {
-  { "EditTask", GTK_STOCK_EDIT, NULL, "<control>e", NULL, G_CALLBACK (on_edit_task_action) },
+  { "EditTask", GTK_STOCK_EDIT, N_("Edit..."), "<control>e", NULL, G_CALLBACK (on_edit_task_action) },
   /* TODO: turn this action into a toggle action */
   { "CompleteTask", NULL, N_("_Mark Complete"), "<control>d", NULL, G_CALLBACK (on_complete_task_action) },
   { "DeleteTask", GTK_STOCK_DELETE, NULL, "<control>Delete", NULL, G_CALLBACK (on_delete_task_action) },
