@@ -24,8 +24,8 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include <osso-uri.h>
-#include <hildon-widgets/hildon-program.h>
+#include <hildon-uri.h>
+#include <hildon/hildon-program.h>
 
 #include <libkoto/ical-util.h>
 #include <libkoto/koto-category-group.h>
@@ -52,7 +52,7 @@ koto_platform_open_url (const char *url)
 {
   GError *error = NULL;
 
-  if (!osso_uri_open (url, NULL, &error)) {
+  if (!hildon_uri_open (url, NULL, &error)) {
     g_warning ("Cannot open URL: %s", error->message);
     g_error_free (error);
   }
@@ -293,7 +293,7 @@ on_complete_task_action (GtkAction *action, gpointer user_data)
 
   gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (filter), &real_iter, &iter);
   
-  koto_task_store_set_done (KOTO_TASK_STORE (task_store), &real_iter, TRUE);
+  koto_task_store_set_done (KOTO_TASK_STORE (task_store), &real_iter, TRUE, NULL);
 }
 
 /*
