@@ -49,6 +49,7 @@ typedef struct _TasksApp
   GtkWidget *notebook;
   GtkWidget *delete_button;
   GtkWidget *main_window;
+  GtkWidget *edit_page;
 
   GtkTreeSelection *selection;
 
@@ -86,8 +87,10 @@ tv_selection_changed (GtkTreeSelection *selection, gpointer userdata)
     }
 
     gtk_widget_set_sensitive (app->delete_button, TRUE);
+    gtk_widget_show (app->edit_page);
   } else {
     gtk_widget_set_sensitive (app->delete_button, FALSE);
+    gtk_widget_hide (app->edit_page);
   }
 
 }
@@ -232,7 +235,7 @@ delete_clicked_cb (GtkToolButton *button, gpointer userdata)
 int
 main (int argc, char **argv)
 {
-  GtkWidget *box, *hbox, *toolbar, *details, *w;
+  GtkWidget *box, *toolbar, *details, *w;
   GtkToolItem *toolitem;
   TasksApp *app;
   ECalView *cal_view;
@@ -320,37 +323,18 @@ main (int argc, char **argv)
   gtk_tool_item_set_expand (toolitem, TRUE);
   gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, 0);
 
-  /* separator */
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), gtk_separator_tool_item_new (),
-                      1);
-
   /* delete */
   toolitem = gtk_tool_button_new_from_stock (GTK_STOCK_DELETE);
   gtk_tool_item_set_expand (toolitem, TRUE);
-  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, 2);
+  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, 1);
   gtk_widget_set_sensitive (GTK_WIDGET (toolitem), FALSE);
   app->delete_button = GTK_WIDGET (toolitem);
 
   g_signal_connect (toolitem, "clicked", G_CALLBACK (delete_clicked_cb), app);
 
   /* search/filter bar */
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
-
-  w = gtk_toggle_button_new ();
-  gtk_widget_set_name (w, "mokosearchbutton");
-  gtk_button_set_image (GTK_BUTTON (w),
-                        gtk_image_new_from_stock (GTK_STOCK_FIND,
-                                                  GTK_ICON_SIZE_SMALL_TOOLBAR));
-  gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
-
-  app->search_entry = gtk_entry_new ();
-  gtk_widget_set_name (app->search_entry, "mokosearchentry");
-  g_object_set (G_OBJECT (app->search_entry), "no-show-all", TRUE, NULL);
-  gtk_box_pack_start (GTK_BOX (hbox), app->search_entry, TRUE, TRUE, 0);
-
   app->filter_combo = koto_group_combo_new (KOTO_GROUP_STORE (app->group_filter_store));
-  gtk_box_pack_start (GTK_BOX (hbox), app->filter_combo, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box), app->filter_combo, FALSE, FALSE, 0);
 
   gtk_combo_box_set_active (GTK_COMBO_BOX (app->filter_combo), 0);
   koto_group_combo_connect_filter (KOTO_GROUP_COMBO (app->filter_combo),
@@ -380,6 +364,11 @@ main (int argc, char **argv)
   gtk_box_pack_start (GTK_BOX (details), app->editor, TRUE, TRUE, 2);
   g_object_set (app->editor, "no-show-all", TRUE, NULL);
 
+  /* show all the widgets on the edit page except the top most as this will be
+   * shown when a task is selected */
+  app->edit_page = alignment;
+  gtk_widget_set_no_show_all (app->edit_page, TRUE);
+  gtk_widget_show_all (details);
   gtk_notebook_append_page (GTK_NOTEBOOK (app->notebook), alignment,
                             gtk_image_new_from_stock (GTK_STOCK_EDIT,
                                                       GTK_ICON_SIZE_LARGE_TOOLBAR));
@@ -391,14 +380,6 @@ main (int argc, char **argv)
   /* let's go! */
   gtk_widget_show_all (app->main_window);
 
-#if 1
-  /* Force theme settings */
-  g_object_set (gtk_settings_get_default (),
-      "gtk-theme-name", "openmoko-standard-2", 
-      "gtk-icon-theme-name", "openmoko-standard",
-      NULL);
-#endif
-
   gtk_main ();
 
   g_free (app);
